RestorableDuration constructor

RestorableDuration(
  1. Duration defaultValue
)

Creates a RestorableDuration.

If no restoration data is available to restore the value in this property from, the property will be initialized with the provided defaultValue.

Implementation

RestorableDuration(Duration defaultValue) : _defaultValue = defaultValue;